@@ -1,10 +1,15 @@
+"""Session interface for Flask.
+"""
 
 from flask.sessions import SecureCookieSessionInterface
 
+
 class SessionInterface(SecureCookieSessionInterface):
+    """Extends secure cookie session interface with better support for
+    permanent sessions."""
     def __init__(self, salt=None, permanent=True):
         if salt:
-            # salt is added on top of secret key
+            # Salt is added on top of secret key.
             self.salt = salt
 
         self.permanent = permanent
@@ -13,12 +18,13 @@ class SessionInterface(SecureCookieSessionInterface):
         session = super(SessionInterface, self).open_session(app, request)
 
         if session is not None and self.permanent:
-            # set session to permanent
             session.permanent = True
 
         return session
 
+
 def init_app(app):
+    """Initialize app."""
     app.config.setdefault('CARAFE_SESSION_ENABLED', True)
     app.config.setdefault('CARAFE_SESSION_PERMANENT', True)
     app.config.setdefault('CARAFE_SESSION_SALT', None)
@@ -26,6 +32,8 @@ def init_app(app):
     if not app.config['CARAFE_SESSION_ENABLED']:
         return
 
-    permanent = app.config['CARAFE_SESSION_PERMANENT'] and app.config['PERMANENT_SESSION_LIFETIME'].total_seconds() > 0
+    permanent = (app.config['PERMANENT_SESSION_LIFETIME'].total_seconds() > 0
+                 and app.config['CARAFE_SESSION_PERMANENT'])
 
-    app.session_interface = SessionInterface(salt=app.config['CARAFE_SESSION_SALT'], permanent=permanent)
+    app.session_interface = SessionInterface(
+        salt=app.config['CARAFE_SESSION_SALT'], permanent=permanent)
